ActiveConnectionState

Enum ActiveConnectionState 

#[non_exhaustive]
pub enum ActiveConnectionState { Unknown, Activating, Activated, Deactivating, Deactivated, Other(u32), }
NetworkManager active connection state.

These values represent the lifecycle states of an active connection as reported by the NM D-Bus API.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unknown

Connection state is unknown.



Activating

Connection is activating (connecting).



Activated

Connection is fully activated (connected).



Deactivating

Connection is deactivating (disconnecting).



Deactivated

Connection is fully deactivated (disconnected).



Other(u32)

Unknown state code not mapped to a specific variant.