#[non_exhaustive]pub enum BluetoothNetworkRole {
PanU,
Dun,
}Expand description
Bluetooth network role.
Specifies the role of the Bluetooth device in the network connection.
Stability
This enum is marked as #[non_exhaustive] so as to assume that new Bluetooth roles may be
added in future versions. When pattern matching, always include a wildcard arm.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.