BluetoothDevice

Struct BluetoothDevice 

#[non_exhaustive]
pub struct BluetoothDevice { pub bdaddr: String, pub name: Option<String>, pub alias: Option<String>, pub bt_caps: u32, pub state: DeviceState, }
Bluetooth device with friendly name from BlueZ.

Contains information about a Bluetooth device managed by NetworkManager, proxying data from BlueZ.

This is a specialized struct for Bluetooth devices, separate from the general Device struct.

Example

Example

use nmrs::models::{BluetoothDevice, BluetoothNetworkRole, DeviceState};

let role = BluetoothNetworkRole::PanU as u32;
let device = BluetoothDevice::new(
    "00:1A:7D:DA:71:13".into(),
    Some("My Phone".into()),
    Some("Phone".into()),
    role,
    DeviceState::Activated,
);

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
bdaddr: String

Bluetooth MAC address

name: Option<String>

Friendly device name from BlueZ

alias: Option<String>

Device alias from BlueZ

bt_caps: u32

Bluetooth device type (DUN or PANU)

state: DeviceState

Current device state

Implementations

Source

impl BluetoothDevice

pub fn new( bdaddr: String, name: Option<String>, alias: Option<String>, bt_caps: u32, state: DeviceState, ) -> Self

Creates a new BluetoothDevice.

Arguments
  • bdaddr - Bluetooth MAC address
  • name - Friendly device name from BlueZ
  • alias - Device alias from BlueZ
  • bt_caps - Bluetooth device capabilities/type
  • state - Current device state
Example
use nmrs::models::{BluetoothDevice, BluetoothNetworkRole, DeviceState};

let role = BluetoothNetworkRole::PanU as u32;
let device = BluetoothDevice::new(
    "00:1A:7D:DA:71:13".into(),
    Some("My Phone".into()),
    Some("Phone".into()),
    role,
    DeviceState::Activated,
);